Module shm

Module shm 

ClockBound Shared Memory

This crate implements the low-level IPC functionality to share ClockErrorBound data and clock status over a shared memory segment. This crate is meant to be used by the C and Rust versions of the ClockBound client library.

Modules

common

Structs

ClockBoundNowResult
Result of the ClockBoundClient::now() function.
ClockErrorBoundGeneric
Generic ClockErrorBound builder.
ClockErrorBoundGenericBuilder
Use builder syntax to set the inputs and finish with build_internal().
ClockErrorBoundV2
Structure that holds the ClockErrorBound data captured at a specific point in time and valid until a subsequent point in time.
ClockErrorBoundV3
Structure that holds the ClockErrorBound data captured at a specific point in time and valid until a subsequent point in time.
ShmReader
Reader for ClockBound daemon shared memory segment.
ShmWriter
Writer to the ClockBound shared memory segment.

Enums

ClockErrorBound
Enum that holds supported layout of the ClockErrorBound stored in the ClockBound daemon shared memory segment.
ClockErrorBoundLayoutVersion
ClockStatus
Definition of mutually exclusive clock status exposed to the reader.
ShmError
Error condition returned by all low-level ClockBound APIs.

Constants

CLOCKBOUND_SHM_CLIENT_DEFAULT_PATH
CLOCKBOUND_SHM_DEFAULT_PATH_V0
CLOCKBOUND_SHM_DEFAULT_PATH_V1

Traits

ClockBoundSnapshot
ShmWrite
Trait that a writer to the shared memory segment has to implement.