#[repr(i32)]pub enum ClockStatus {
Unknown = 0,
Synchronized = 1,
FreeRunning = 2,
Disrupted = 3,
}Expand description
Definition of mutually exclusive clock status exposed to the reader.
Note the data layout is explicitly set to i32. This enum is a field of the ClockBound shared memory segment, and its representation may be different for C code compiled with specific flags. Making it explicit removes this risk and ambiguity.
Variants
Unknown = 0
The status of the clock is unknown. In this clock status, error-bounded timestamps should not be trusted.
Synchronized = 1
The clock is kept accurate by the synchronization daemon. In this clock status, error-bounded timestamps can be trusted.
FreeRunning = 2
The clock is free running and not updated by the synchronization daemon. In this clock status, error-bounded timestamps can be trusted.
Disrupted = 3
The clock has been disrupted and the accuracy of time cannot be bounded. In this clock status, error-bounded timestamps should not be trusted.