pub struct ShmWriter { /* private fields */ }Expand description
Writer to the ClockBound shared memory segment.
This writer is expected to be used by a single process writing to a given path. The file written to is memory mapped by the writer and many (read-only) readers. Updates to the memory segment are applied in a lock-free manner, using a rolling generation number to protect the update section.
Implementations
Sourceimpl ShmWriter
impl ShmWriter
Sourcepub fn new(
path: &Path,
minimum_version: ClockErrorBoundLayoutVersion,
current_version: ClockErrorBoundLayoutVersion,
) -> Result<ShmWriter>
pub fn new( path: &Path, minimum_version: ClockErrorBoundLayoutVersion, current_version: ClockErrorBoundLayoutVersion, ) -> Result<ShmWriter>
Create a new ShmWriter referencing the memory segment to write ClockErrorBound data to.
There are several cases to consider:
- The file backing the memory segment does not exist, or the content is corrupted/wrong. This is a cold start-like scenario, creating a fresh memory mapped file.
- The file backing the memory segment already exist and is valid. This may be that the process using this writer has restarted, but clients may still be using the existing values. Here, we want to load the existing memory segment, and continue as if nothing happened. That’s a warm reboot-like scenario.
- A variation of 2., but where the layout is being changed (a version bump). This is analog to a cold boot.