pub trait ShmWrite {
// Required method
fn write(&mut self, ceb: &ClockErrorBound);
}Expand description
Trait that a writer to the shared memory segment has to implement.
Required Methods
Sourcefn write(&mut self, ceb: &ClockErrorBound)
fn write(&mut self, ceb: &ClockErrorBound)
Update the shared memory segment with updated clock error bound data.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".