ClockBound Shared Memory
This crate implements the low-level IPC functionality to share ClockErrorBound data and clock
status over a shared memory segment. This crate is meant to be used by the C and Rust versions
of the ClockBound client library.
Modules
Structs
- Clock
Bound NowResult - Result of the
ClockBoundClient::now()function. - Clock
Error Bound Generic - Generic
ClockErrorBoundbuilder. - Clock
Error Bound Generic Builder - Use builder syntax to set the inputs and finish with
build_internal(). - Clock
Error Bound V2 - Structure that holds the
ClockErrorBounddata captured at a specific point in time and valid until a subsequent point in time. - Clock
Error Bound V3 - Structure that holds the
ClockErrorBounddata captured at a specific point in time and valid until a subsequent point in time. - ShmReader
- Reader for ClockBound daemon shared memory segment.
- ShmWriter
- Writer to the ClockBound shared memory segment.
Enums
- Clock
Error Bound - Enum that holds supported layout of the
ClockErrorBoundstored in the ClockBound daemon shared memory segment. - Clock
Error Bound Layout Version - Clock
Status - Definition of mutually exclusive clock status exposed to the reader.
- ShmError
- Error condition returned by all low-level ClockBound APIs.
Constants
Traits
- Clock
Bound Snapshot - ShmWrite
- Trait that a writer to the shared memory segment has to implement.