pub trait ClockBoundSnapshot {
// Required method
fn now(&self) -> Result<ClockBoundNowResult, ShmError>;
}Required Methods
Sourcefn now(&self) -> Result<ClockBoundNowResult, ShmError>
fn now(&self) -> Result<ClockBoundNowResult, ShmError>
The ClockErrorBound equivalent of clock_gettime(), but with bound on accuracy.
Returns a ClockBoundNowResult with contains the (earliest, latest) timespec between which
current time exists. The interval width is twice the clock error bound (ceb) such that:
(earliest, latest) = ((now - ceb), (now + ceb))
The function also returns a clock status to assert that the clock is being synchronized, or free-running, or …
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".